ITIP20FactoryInstance

Struct ITIP20FactoryInstance 

pub struct ITIP20FactoryInstance<P, N = Ethereum> {
    address: Address,
    provider: P,
    _network: PhantomData<N>,
}
A ITIP20Factory instance.

Contains type-safe methods for interacting with an on-chain instance of the ITIP20Factory contract located at a given address, using a given provider P.

If the contract bytecode is available (see the sol! documentation on how to provide it), the deploy and deploy_builder methods can be used to deploy a new instance of the contract.

See the module-level documentation for all the available methods.

Fields

address: Addressprovider: P_network: PhantomData<N>

Implementations

Source

impl<P: Provider<N>, N: Network> ITIP20FactoryInstance<P, N>

Instantiation and getters/setters.

pub const fn new(address: Address, __provider: P) -> Self

Creates a new wrapper around an on-chain ITIP20Factory contract instance.

See the wrapper’s documentation for more details.

pub const fn address(&self) -> &Address

Returns a reference to the address.

pub fn set_address(&mut self, address: Address)

Sets the address.

pub fn at(self, address: Address) -> Self

Sets the address and returns self.

pub const fn provider(&self) -> &P

Returns a reference to the provider.

Source

impl<P: Clone, N> ITIP20FactoryInstance<&P, N>

pub fn with_cloned_provider(self) -> ITIP20FactoryInstance<P, N>

Clones the provider and returns a new instance with the cloned provider.

Source

impl<P: Provider<N>, N: Network> ITIP20FactoryInstance<P, N>

Function calls.

pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>

Creates a new call builder using this contract instance’s provider and address.

Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.

pub fn createToken( &self, name: String, symbol: String, currency: String, quoteToken: Address, admin: Address, salt: FixedBytes<32>, ) -> SolCallBuilder<&P, createTokenCall, N>

Creates a new call builder for the [createToken] function.

pub fn isTIP20(&self, token: Address) -> SolCallBuilder<&P, isTIP20Call, N>

Creates a new call builder for the [isTIP20] function.

pub fn getTokenAddress( &self, sender: Address, salt: FixedBytes<32>, ) -> SolCallBuilder<&P, getTokenAddressCall, N>

Creates a new call builder for the [getTokenAddress] function.

Source

impl<P: Provider<N>, N: Network> ITIP20FactoryInstance<P, N>

Event filters.

pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>

Creates a new event filter using this contract instance’s provider and address.

Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.

pub fn TokenCreated_filter(&self) -> Event<&P, TokenCreated, N>

Creates a new event filter for the TokenCreated event.