pub struct createToken_1Call {
pub name: String,
pub symbol: String,
pub currency: String,
pub quoteToken: Address,
pub admin: Address,
pub salt: FixedBytes<32>,
pub logoURI: String,
}Expand description
@notice Creates a token and sets its logoURI atomically (TIP-1026).
@dev Solidity overload of createToken with an additional logoURI argument.
Reverts with LogoURITooLong if bytes(logoURI).length > 256, or
with InvalidLogoURI if logoURI is non-empty and either has no
parseable scheme or its scheme is not in the allow-list.
Function with signature createToken(string,string,string,address,address,bytes32,string) and selector 0x5323d222.
function createToken(string memory name, string memory symbol, string memory currency, address quoteToken, address admin, bytes32 salt, string memory logoURI) external returns (address);Fields
name: Stringsymbol: Stringcurrency: StringquoteToken: Addressadmin: Addresssalt: FixedBytes<32>logoURI: StringTrait Implementations
Sourceimpl Clone for createToken_1Call
impl Clone for createToken_1Call
Sourcefn clone(&self) -> createToken_1Call
fn clone(&self) -> createToken_1Call
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for createToken_1Call
impl Debug for createToken_1Call
Sourceimpl<'de> Deserialize<'de> for createToken_1Call
impl<'de> Deserialize<'de> for createToken_1Call
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for createToken_1Call
Sourceimpl JsonAbiExt for createToken_1Call
impl JsonAbiExt for createToken_1Call
Sourceimpl PartialEq for createToken_1Call
impl PartialEq for createToken_1Call
Sourcefn eq(&self, other: &createToken_1Call) -> bool
fn eq(&self, other: &createToken_1Call) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for createToken_1Call
impl Serialize for createToken_1Call
Sourceimpl SolCall for createToken_1Call
impl SolCall for createToken_1Call
Sourceconst SIGNATURE: &'static str = "createToken(string,string,string,address,address,bytes32,string)"
const SIGNATURE: &'static str = "createToken(string,string,string,address,address,bytes32,string)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (String, String, String, Address, Address, FixedBytes<32>, String)
type Parameters<'a> = (String, String, String, Address, Address, FixedBytes<32>, String)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<createToken_1Call as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<createToken_1Call as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding [TokenSeq] type.
Sourcetype ReturnTuple<'a> = (Address,)
type ReturnTuple<'a> = (Address,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<createToken_1Call as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<createToken_1Call as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding [TokenSeq] type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the call to the given buffer with its selector.
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
ABI encode the call’s return value.
impl StructuralPartialEq for createToken_1Call